@@ -1,19 +1,14 @@
-// File Description
-/// \file BamFile.h
-/// \brief Defines the BamFile class.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_BAMFILE_H
+#define PBBAM_BAMFILE_H
 
-#ifndef BAMFILE_H
-#define BAMFILE_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <cstdint>
 
+#include <memory>
 #include <string>
 
-#include "pbbam/BamHeader.h"
+#include <pbbam/BamHeader.h>
 
 namespace PacBio {
 namespace BAM {
@@ -161,18 +156,6 @@ public:
 
     /// \}
 
-public:
-    /// \name Additional Attributes
-    /// \{
-
-    /// \returns virtual offset of first alignment. Intended mostly for internal
-    ///          use. Note that this is a BGZF \b virtual offset, not a
-    ///          'normal' file position.
-    ///
-    int64_t FirstAlignmentOffset() const;
-
-    /// \}
-
 private:
     class BamFilePrivate;
     std::unique_ptr<BamFilePrivate> d_;
@@ -181,4 +164,4 @@ private:
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // BAMFILE_H
+#endif  // PBBAM_BAMFILE_H
