@@ -1,13 +1,7 @@
-// File Description
-/// \file BamRecordImpl.h
-/// \brief Defines the BamRecordImpl class.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_BAMRECORDIMPL_H
+#define PBBAM_BAMRECORDIMPL_H
 
-#ifndef BAMRECORDIMPL_H
-#define BAMRECORDIMPL_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <cstddef>
 #include <cstdint>
@@ -19,11 +13,12 @@
 
 #include <htslib/sam.h>
 
-#include "pbbam/BamRecordTag.h"
-#include "pbbam/Cigar.h"
-#include "pbbam/Position.h"
-#include "pbbam/QualityValues.h"
-#include "pbbam/TagCollection.h"
+#include <pbbam/BamRecordTag.h>
+#include <pbbam/Cigar.h>
+#include <pbbam/Deleters.h>
+#include <pbbam/Position.h>
+#include <pbbam/QualityValues.h>
+#include <pbbam/TagCollection.h>
 
 namespace PacBio {
 namespace BAM {
@@ -70,7 +65,7 @@ public:
     BamRecordImpl(BamRecordImpl&& other) noexcept = default;
     BamRecordImpl& operator=(const BamRecordImpl& other);
     BamRecordImpl& operator=(BamRecordImpl&& other) noexcept = default;
-    virtual ~BamRecordImpl() = default;
+    ~BamRecordImpl();
 
     /// \}
 
@@ -91,13 +86,13 @@ public:
     uint8_t MapQuality() const;
 
     /// \returns this record's mate's mapped position, or -1 if unmapped
-    PacBio::BAM::Position MatePosition() const;
+    Data::Position MatePosition() const;
 
     /// \returns this record's mate's mapped reference ID, or -1 if unmapped
     int32_t MateReferenceId() const;
 
     /// \returns this record's mapped position, or -1 if unmapped
-    PacBio::BAM::Position Position() const;
+    Data::Position Position() const;
 
     /// \returns this record's mate's mapped reference ID, or -1 if unmapped
     int32_t ReferenceId() const;
@@ -135,7 +130,7 @@ public:
     /// \param[in] pos mapped position. A value of -1 indicates unmapped.
     /// \returns reference to this record
     ///
-    BamRecordImpl& MatePosition(PacBio::BAM::Position pos);
+    BamRecordImpl& MatePosition(Data::Position pos);
 
     /// Sets this record's mate's mapped reference ID
     ///
@@ -149,7 +144,7 @@ public:
     /// \param[in] pos mapped position. A value of -1 indicates unmapped.
     /// \returns reference to this record
     ///
-    BamRecordImpl& Position(PacBio::BAM::Position pos);
+    BamRecordImpl& Position(Data::Position pos);
 
     /// Sets this record's mapped reference ID
     ///
@@ -243,14 +238,14 @@ public:
     /// \{
 
     /// \returns the record's CIGAR data as a Cigar object
-    Cigar CigarData() const;
+    Data::Cigar CigarData() const;
 
     /// Sets the record's CIGAR data using a Cigar object
     ///
     /// \param[in] cigar PacBio::BAM::Cigar object
     /// \returns reference to this record
     ///
-    BamRecordImpl& CigarData(const Cigar& cigar);
+    BamRecordImpl& CigarData(const Data::Cigar& cigar);
 
     /// Sets the record's CIGAR data using a CIGAR-formatted string.
     ///
@@ -277,7 +272,7 @@ public:
     ///       some data sets, the quality values are not provided. In that
     ///       case, this method will return an empty container.
     ///
-    QualityValues Qualities() const;
+    Data::QualityValues Qualities() const;
 
     /// \returns the record's DNA sequence.
     std::string Sequence() const;
@@ -571,7 +566,7 @@ private:
     int TagOffset(const std::string& tagName) const;
 
     // internal CIGAR handling
-    void SetCigarData(const Cigar& cigar);
+    void SetCigarData(const Data::Cigar& cigar);
 
     // core seq/qual logic shared by the public API
     BamRecordImpl& SetSequenceAndQualitiesInternal(const char* sequence,
@@ -580,7 +575,7 @@ private:
 
 private:
     // data members
-    std::shared_ptr<bam1_t> d_;
+    std::unique_ptr<bam1_t, HtslibRecordDeleter> d_;
     mutable std::unordered_map<uint16_t, int> tagOffsets_;
 
     // friends
@@ -593,4 +588,4 @@ private:
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // BAMRECORDIMPL_H
+#endif  // PBBAM_BAMRECORDIMPL_H
