@@ -1,26 +1,16 @@
-// File Description
-/// \file BgzipFastaWriter.h
-/// \brief Defines the BgzipFastaWriter class.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_BGZIPFASTAWRITER_H
+#define PBBAM_BGZIPFASTAWRITER_H
 
-#ifndef BGZIPFASTAWRITER_H
-#define BGZIPFASTAWRITER_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <string>
 
-#include "pbbam/BgzipWriter.h"
-#include "pbbam/IFastaWriter.h"
+#include <pbbam/BgzipWriter.h>
+#include <pbbam/IFastaWriter.h>
 
 namespace PacBio {
 namespace BAM {
 
-class BamRecord;
-class BamRecordImpl;
-class FastaSequence;
-
 class BgzipFastaWriter final : public IFastaWriter
 {
 public:
@@ -33,7 +23,6 @@ public:
     void Write(const std::string& name, const std::string& bases);
 
     // IRecordWriter
-    void TryFlush();
     void Write(const BamRecord& bam);
     void Write(const BamRecordImpl& bam);
 
@@ -44,4 +33,4 @@ private:
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // BGZIPFASTAWRITER_H
+#endif  // PBBAM_BGZIPFASTAWRITER_H
