@@ -1,13 +1,7 @@
-// File Description
-/// \file ReadGroupInfo.h
-/// \brief Defines the ReadGroupInfo class.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_READGROUPINFO_H
+#define PBBAM_READGROUPINFO_H
 
-#ifndef READGROUPINFO_H
-#define READGROUPINFO_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <cstddef>
 #include <cstdint>
@@ -18,7 +12,10 @@
 
 #include <boost/optional.hpp>
 
-#include "pbbam/exception/InvalidSequencingChemistryException.h"
+#include <pbcopper/data/FrameCodec.h>
+#include <pbcopper/data/FrameEncoders.h>
+
+#include <pbbam/exception/InvalidSequencingChemistryException.h>
 
 namespace PacBio {
 namespace BAM {
@@ -54,16 +51,7 @@ enum class BaseFeature
     PULSE_EXCLUSION
 };
 
-/// \brief This enum describes the encoding types used for frame data within a
-///        read group's records.
-///
-/// This information is stored in its description (\@RG:DS).
-///
-enum class FrameCodec
-{
-    RAW,
-    V1
-};
+using FrameCodec PBBAM_DEPRECATED = Data::FrameCodec;
 
 /// \brief This enum describes the experimental design of the barcodes within a
 ///        read group's records.
@@ -235,10 +223,10 @@ public:
     /// \name Comparison Operators
     /// \{
 
-    bool operator==(const ReadGroupInfo& other) const;
+    bool operator==(const ReadGroupInfo& other) const noexcept;
 
     /// Enable sort on RG:ID
-    bool operator<(const ReadGroupInfo& other) const;
+    bool operator<(const ReadGroupInfo& other) const noexcept;
 
     /// \}
 
@@ -403,7 +391,10 @@ public:
     std::string Id() const;
 
     /// \returns codec type in use for IPD
-    FrameCodec IpdCodec() const;
+    Data::FrameCodec IpdCodec() const;
+
+    /// \returns codec implementation in use for IPD
+    Data::FrameEncoder IpdFrameEncoder() const;
 
     /// \returns string value of \@RG:KS
     std::string KeySequence() const;
@@ -427,7 +418,10 @@ public:
     std::string Programs() const;
 
     /// \returns codec type in use for PulseWidth
-    FrameCodec PulseWidthCodec() const;
+    Data::FrameCodec PulseWidthCodec() const;
+
+    /// \returns codec implementation in use for PulseWidth
+    Data::FrameEncoder PulseWidthFrameEncoder() const;
 
     /// \returns string value of read type
     std::string ReadType() const;
@@ -573,7 +567,15 @@ public:
     /// \param[in] tag      IPD tag
     /// \returns reference to this object
     ///
-    ReadGroupInfo& IpdCodec(FrameCodec codec, std::string tag = std::string());
+    ReadGroupInfo& IpdCodec(Data::FrameCodec codec, std::string tag = std::string());
+
+    /// \brief Sets the codec implementation used for IPD
+    ///
+    /// \param[in] encoder  codec implementation
+    /// \param[in] tag      IPD tag
+    /// \returns reference to this object
+    ///
+    ReadGroupInfo& IpdFrameEncoder(Data::FrameEncoder encoder);
 
     /// \brief Sets the value for \@RG:KS
     ///
@@ -623,7 +625,14 @@ public:
     /// \param[in] tag      pulse width tag
     /// \returns reference to this object
     ///
-    ReadGroupInfo& PulseWidthCodec(FrameCodec codec, std::string tag = std::string());
+    ReadGroupInfo& PulseWidthCodec(Data::FrameCodec codec, std::string tag = std::string());
+
+    /// \brief Sets the codec implementation to use for PulseWidth
+    ///
+    /// \param[in] encoder  codec implementation
+    /// \returns reference to this object
+    ///
+    ReadGroupInfo& PulseWidthFrameEncoder(Data::FrameEncoder encoder);
 
     /// \brief Sets the read type.
     ///
@@ -684,8 +693,8 @@ private:
     mutable std::string sequencingChemistry_;
     std::string frameRateHz_;
     bool control_ = false;
-    FrameCodec ipdCodec_ = FrameCodec::V1;
-    FrameCodec pulseWidthCodec_ = FrameCodec::V1;
+    Data::FrameCodec ipdCodec_ = Data::FrameCodec::V1;
+    Data::FrameCodec pulseWidthCodec_ = Data::FrameCodec::V1;
     bool hasBarcodeData_ = false;
     std::string barcodeFile_;
     std::string barcodeHash_;
@@ -698,6 +707,9 @@ private:
     boost::optional<std::pair<uint16_t, uint16_t>> barcodes_ = boost::none;
     std::string baseId_;
 
+    Data::FrameEncoder ipdEncoder_ = Data::V1FrameEncoder{};
+    Data::FrameEncoder pulseWidthEncoder_ = Data::V1FrameEncoder{};
+
     // custom attributes
     std::map<std::string, std::string> custom_;  // tag => value
 
@@ -747,4 +759,4 @@ std::string MakeReadGroupId(const std::string& movieName, const std::string& rea
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // READGROUPINFO_H
+#endif  // PBBAM_READGROUPINFO_H
