@@ -1,14 +1,7 @@
-
-// File Description
-/// \file TextFileWriter.h
-/// \brief Defines the TextFileWriter class.
-//
-// Author: Derek Barnett
-
 #ifndef PBBAM_TEXTFILEWRITER_H
 #define PBBAM_TEXTFILEWRITER_H
 
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <memory>
 #include <string>
@@ -57,4 +50,4 @@ private:
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // PBBAM_TEXTFILEWRITER_H
\ No newline at end of file
+#endif  // PBBAM_TEXTFILEWRITER_H
