@@ -1,11 +1,7 @@
-// Author: Derek Barnett
+#ifndef PBBAM_DATASETELEMENT_H
+#define PBBAM_DATASETELEMENT_H
 
-#ifndef DATASETELEMENT_H
-#define DATASETELEMENT_H
-
-#include "pbbam/Config.h"
-
-#include "pbbam/DataSetXsd.h"
+#include <pbbam/Config.h>
 
 #include <cassert>
 
@@ -18,6 +14,8 @@
 
 #include <boost/utility/string_ref.hpp>
 
+#include <pbbam/DataSetXsd.h>
+
 namespace PacBio {
 namespace BAM {
 namespace internal {
@@ -37,8 +35,8 @@ public:
     XmlName(const std::string& localName, const std::string& prefix);
 
 public:
-    bool operator==(const XmlName& other) const;
-    bool operator!=(const XmlName& other) const;
+    bool operator==(const XmlName& other) const noexcept;
+    bool operator!=(const XmlName& other) const noexcept;
 
 public:
     const boost::string_ref LocalName() const;
@@ -68,8 +66,8 @@ public:
     virtual ~DataSetElement() = default;
 
 public:
-    bool operator==(const DataSetElement& other) const;
-    bool operator!=(const DataSetElement& other) const;
+    bool operator==(const DataSetElement& other) const noexcept;
+    bool operator!=(const DataSetElement& other) const noexcept;
 
 public:
     const std::string& Attribute(const std::string& name) const;
@@ -156,8 +154,8 @@ private:
 class DataSetElementIteratorBase
 {
 public:
-    bool operator==(const DataSetElementIteratorBase& other) const;
-    bool operator!=(const DataSetElementIteratorBase& other) const;
+    bool operator==(const DataSetElementIteratorBase& other) const noexcept;
+    bool operator!=(const DataSetElementIteratorBase& other) const noexcept;
 
 protected:
     DataSetElementIteratorBase(const DataSetElement* parent, size_t i);
@@ -174,8 +172,8 @@ class DataSetElementIterator : public DataSetElementIteratorBase
 public:
     DataSetElementIterator(const DataSetElement* parent, size_t i);
 
-    T& operator*();
-    T* operator->();
+    T& operator*() noexcept;
+    T* operator->() noexcept;
 
     DataSetElementIterator& operator++();
     DataSetElementIterator operator++(int);
@@ -187,8 +185,8 @@ class DataSetElementConstIterator : public DataSetElementIteratorBase
 public:
     DataSetElementConstIterator(const DataSetElement* parent, size_t i);
 
-    const T& operator*() const;
-    const T* operator->() const;
+    const T& operator*() const noexcept;
+    const T* operator->() const noexcept;
 
     DataSetElementConstIterator& operator++();
     DataSetElementConstIterator operator++(int);
@@ -198,6 +196,6 @@ public:
 }  // namespace BAM
 }  // namespace PacBio
 
-#include "pbbam/internal/DataSetElement.inl"
+#include <pbbam/internal/DataSetElement.inl>
 
-#endif  // DATASETELEMENT_H
+#endif  // PBBAM_DATASETELEMENT_H
