@@ -1,8 +1,7 @@
-
 #ifndef PBBAM_VCF_VCFHEADERTYPES_H
 #define PBBAM_VCF_VCFHEADERTYPES_H
 
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <string>
 #include <utility>
