@@ -1,12 +1,11 @@
-// Author: Derek Barnett
-
 #ifndef PBBAM_VCF_VCFQUERY_H
 #define PBBAM_VCF_VCFQUERY_H
 
+#include <pbbam/Config.h>
+
 #include <string>
 
 #include <pbbam/internal/QueryBase.h>
-
 #include <pbbam/vcf/VcfFile.h>
 #include <pbbam/vcf/VcfReader.h>
 #include <pbbam/vcf/VcfVariant.h>
@@ -14,19 +13,12 @@
 namespace PacBio {
 namespace VCF {
 
-class VcfQuery : public PacBio::BAM::internal::QueryBase<VcfVariant>
+class VcfQuery : public BAM::internal::QueryBase<VcfVariant>
 {
 public:
     explicit VcfQuery(std::string fn);
     explicit VcfQuery(const VcfFile& file);
 
-    VcfQuery() = default;
-    VcfQuery(const VcfQuery&) = delete;
-    VcfQuery(VcfQuery&&) = default;
-    VcfQuery& operator=(const VcfQuery&) = delete;
-    VcfQuery& operator=(VcfQuery&&) = default;
-    ~VcfQuery() = default;
-
 public:
     /// \brief Main iteration point for record access.
     ///
