@@ -1,12 +1,9 @@
-// Author: Derek Barnett
-
 #ifndef PBBAM_VCF_VCFREADER_H
 #define PBBAM_VCF_VCFREADER_H
 
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <fstream>
-#include <iostream>
 #include <memory>
 #include <string>
 
