@@ -1,13 +1,11 @@
-// Author: Derek Barnett
-
 #ifndef PBBAM_VCF_VCFSORT_H
 #define PBBAM_VCF_VCFSORT_H
 
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include <string>
 
-#include "pbbam/vcf/VcfFile.h"
+#include <pbbam/vcf/VcfFile.h>
 
 namespace PacBio {
 namespace VCF {
