@@ -18,9 +18,9 @@ if [[ ${GCC_VERSION} == PA ]]; then
     ninja -C build -v install
   popd
 
-  wget https://github.com/samtools/htslib/releases/download/1.9/htslib-1.9.tar.bz2
-  tar -xjf htslib-1.9.tar.bz2
-  pushd htslib-1.9
+  wget https://github.com/samtools/htslib/releases/download/1.10.2/htslib-1.10.2.tar.bz2
+  tar -xjf htslib-1.10.2.tar.bz2
+  pushd htslib-1.10.2
     CFLAGS="-O3" ./configure \
       --prefix="${bamboo_build_working_directory}/staging" \
       --libdir="${bamboo_build_working_directory}/staging/lib" \
@@ -60,6 +60,7 @@ meson \
   -Db_coverage="${ENABLED_COVERAGE:-false}" \
   -Db_lto="${ENABLED_LTO:-false}" \
   -Db_sanitize="${ENABLED_SANITIZERS:-none}" \
+  -Db_lundef="${ENABLED_LUNDEF:-true}" \
   -Dcpp_debugstl="${ENABLED_DEBUGSTL:-false}" \
   -Dtests="${ENABLED_TESTS:-false}" \
   "${CURRENT_BUILD_DIR:-build}" .
