@@ -1,22 +1,17 @@
-// File Description
-/// \file BaiIndexCache.cpp
-/// \brief Implements the BaiIndexCache class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/BaiIndexCache.h"
+#include <pbbam/BaiIndexCache.h>
 
 #include <sstream>
 #include <stdexcept>
 
 #include <htslib/sam.h>
 
-#include "pbbam/BamFile.h"
-#include "pbbam/DataSet.h"
+#include <pbbam/BamFile.h>
+#include <pbbam/DataSet.h>
+#include <pbbam/Deleters.h>
 
-#include "MemoryUtils.h"
+#include "ErrnoReason.h"
 
 namespace PacBio {
 namespace BAM {
@@ -37,17 +32,18 @@ BaiIndexCacheData::BaiIndexCacheData(const std::string& bamFilename)
     d_->htsIndex_.reset(bam_index_load(bamFilename.c_str()));
     if (!d_->htsIndex_) {
         std::ostringstream s;
-        s << "[pbbam] BAI index cache ERROR: could not load *.bai index data:\n"
+        s << "[pbbam] BAI index cache ERROR: could not load BAI index data:\n"
           << "  BAM file: " << bamFilename << '\n'
           << "  BAI file: " + bamFilename + ".bai";
+        MaybePrintErrnoReason(s);
         throw std::runtime_error{s.str()};
     }
 }
 
 BaiIndexCacheData::~BaiIndexCacheData() = default;
 
-hts_itr_t* BaiIndexCacheData::IteratorForInterval(const int32_t refId, const Position start,
-                                                  const Position stop) const
+hts_itr_t* BaiIndexCacheData::IteratorForInterval(const int32_t refId, const Data::Position start,
+                                                  const Data::Position stop) const
 {
     return bam_itr_queryi(d_->htsIndex_.get(), refId, start, stop);
 }
@@ -61,7 +57,7 @@ BaiIndexCache MakeBaiIndexCache(const DataSet& dataset)
 
 BaiIndexCache MakeBaiIndexCache(const std::vector<BamFile>& bamFiles)
 {
-    BaiIndexCache cache = std::make_shared<std::vector<std::shared_ptr<BaiIndexCacheData>>>();
+    auto cache = std::make_shared<std::vector<std::shared_ptr<BaiIndexCacheData>>>();
     auto& indices = *cache.get();
     for (const auto& bamFile : bamFiles)
         indices.push_back(std::make_shared<BaiIndexCacheData>(bamFile));
