@@ -1,8 +1,6 @@
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/BamRecordImpl.h"
+#include <pbbam/BamRecordImpl.h>
 
 #include <cassert>
 #include <cstddef>
@@ -12,14 +10,14 @@
 
 #include <algorithm>
 #include <array>
-#include <iostream>
+#include <sstream>
 #include <tuple>
 #include <utility>
 
 #include <htslib/hts_endian.h>
 
-#include "pbbam/BamTagCodec.h"
-#include "pbbam/StringUtilities.h"
+#include <pbbam/BamTagCodec.h>
+#include <pbbam/StringUtilities.h>
 
 #include "BamRecordTags.h"
 #include "MemoryUtils.h"
@@ -31,14 +29,14 @@ namespace {
 
 static const bool has_native_long_cigar_support = DoesHtslibSupportLongCigar();
 
-Cigar FetchRawCigar(const uint32_t* const src, const uint32_t len)
+Data::Cigar FetchRawCigar(const uint32_t* const src, const uint32_t len)
 {
-    Cigar result;
+    Data::Cigar result;
     result.reserve(len);
     for (uint32_t i = 0; i < len; ++i) {
         const uint32_t length = bam_cigar_oplen(src[i]);
-        const auto type = static_cast<CigarOperationType>(bam_cigar_op(src[i]));
-        result.push_back(CigarOperation(type, length));
+        const auto type = static_cast<Data::CigarOperationType>(bam_cigar_op(src[i]));
+        result.push_back({type, length});
     }
     return result;
 }
@@ -52,7 +50,7 @@ bool HasLongCigar(const bam1_t* const b)
 
     // if existing CIGAR doesn't look like a 'fake CIGAR'
     const auto firstCigarOp = *(bam_get_cigar(b));
-    if (bam_cigar_op(firstCigarOp) != static_cast<uint32_t>(CigarOperationType::SOFT_CLIP) ||
+    if (bam_cigar_op(firstCigarOp) != static_cast<uint32_t>(Data::CigarOperationType::SOFT_CLIP) ||
         static_cast<int32_t>(bam_cigar_oplen(firstCigarOp)) != c->l_qseq) {
         return false;
     }
@@ -80,7 +78,7 @@ BamRecordImpl::BamRecordImpl() : d_{nullptr}
 }
 
 BamRecordImpl::BamRecordImpl(const BamRecordImpl& other)
-    : d_{bam_dup1(other.d_.get()), HtslibRecordDeleter()}, tagOffsets_{other.tagOffsets_}
+    : d_{bam_dup1(other.d_.get())}, tagOffsets_{other.tagOffsets_}
 {
     assert(d_);
 }
@@ -89,13 +87,19 @@ BamRecordImpl& BamRecordImpl::operator=(const BamRecordImpl& other)
 {
     if (this != &other) {
         if (d_ == nullptr) InitializeData();
-        bam_copy1(d_.get(), other.d_.get());
+        auto* copyOk = bam_copy1(d_.get(), other.d_.get());
+        if (!copyOk) {
+            throw std::runtime_error{"[pbbam] BAM record ERROR: could not copy data from record '" +
+                                     other.Name() + '\''};
+        }
         tagOffsets_ = other.tagOffsets_;
     }
     assert(d_);
     return *this;
 }
 
+BamRecordImpl::~BamRecordImpl() = default;
+
 bool BamRecordImpl::AddTag(const std::string& tagName, const Tag& value)
 {
     return AddTag(tagName, value, TagModifier::NONE);
@@ -140,7 +144,7 @@ BamRecordImpl& BamRecordImpl::Bin(uint32_t bin)
     return *this;
 }
 
-Cigar BamRecordImpl::CigarData() const
+Data::Cigar BamRecordImpl::CigarData() const
 {
     const auto* b = d_.get();
     if (!has_native_long_cigar_support && HasLongCigar(b)) {
@@ -154,16 +158,16 @@ Cigar BamRecordImpl::CigarData() const
     }
 }
 
-BamRecordImpl& BamRecordImpl::CigarData(const Cigar& cigar)
+BamRecordImpl& BamRecordImpl::CigarData(const Data::Cigar& cigar)
 {
     // if long CIGAR, using htslib version < 1.7, set it "manually"
     if (!has_native_long_cigar_support && cigar.size() >= 65536) {
         // Add the 'fake' CIGAR in normal place.
-        Cigar fake;
-        fake.emplace_back(CigarOperationType::SOFT_CLIP, SequenceLength());
+        Data::Cigar fake;
+        fake.emplace_back(Data::CigarOperationType::SOFT_CLIP, SequenceLength());
         const uint32_t alignedLength =
             static_cast<uint32_t>(bam_cigar2rlen(d_->core.n_cigar, bam_get_cigar(d_.get())));
-        fake.emplace_back(CigarOperationType::REFERENCE_SKIP, alignedLength);
+        fake.emplace_back(Data::CigarOperationType::REFERENCE_SKIP, alignedLength);
         SetCigarData(fake);
 
         // Add raw CIGAR data to CG tag.
@@ -233,7 +237,11 @@ BamRecordImpl& BamRecordImpl::Flag(uint32_t flag)
 BamRecordImpl BamRecordImpl::FromRawData(const std::shared_ptr<bam1_t>& rawData)
 {
     BamRecordImpl result;
-    bam_copy1(result.d_.get(), rawData.get());
+    auto* copyOk = bam_copy1(result.d_.get(), rawData.get());
+    if (!copyOk) {
+        throw std::runtime_error{
+            "[pbbam] BAM record ERROR: could not create record, copying from raw BAM contents"};
+    }
     return result;
 }
 
@@ -250,23 +258,18 @@ bool BamRecordImpl::HasTag(const BamRecordTag tag) const
 
 void BamRecordImpl::InitializeData()
 {
-    d_.reset(bam_init1(), HtslibRecordDeleter());
-    d_->data = static_cast<uint8_t*>(
-        calloc(0x800, sizeof(uint8_t)));  // maybe make this value tune-able later?
-    d_->m_data = 0x800;
+    d_.reset(bam_init1());
 
     // init unmapped
-    Position(PacBio::BAM::UnmappedPosition);
-    MatePosition(PacBio::BAM::UnmappedPosition);
+    Position(Data::UnmappedPosition);
+    MatePosition(Data::UnmappedPosition);
     ReferenceId(-1);
     MateReferenceId(-1);
     SetMapped(false);
     MapQuality(255);
 
-    // initialized with empty qname (null term + 3 'extra nulls' for alignment
-    d_->core.l_extranul = 3;
-    d_->core.l_qname = 4;
-    d_->l_data = 4;
+    // init empty QNAME
+    Name("");
 }
 
 int32_t BamRecordImpl::InsertSize() const { return d_->core.isize; }
@@ -327,9 +330,9 @@ BamRecordImpl& BamRecordImpl::MapQuality(uint8_t mapQual)
     return *this;
 }
 
-PacBio::BAM::Position BamRecordImpl::MatePosition() const { return d_->core.mpos; }
+Data::Position BamRecordImpl::MatePosition() const { return d_->core.mpos; }
 
-BamRecordImpl& BamRecordImpl::MatePosition(PacBio::BAM::Position pos)
+BamRecordImpl& BamRecordImpl::MatePosition(Data::Position pos)
 {
     d_->core.mpos = pos;
     return *this;
@@ -343,9 +346,9 @@ BamRecordImpl& BamRecordImpl::MateReferenceId(int32_t id)
     return *this;
 }
 
-PacBio::BAM::Position BamRecordImpl::Position() const { return d_->core.pos; }
+Data::Position BamRecordImpl::Position() const { return d_->core.pos; }
 
-BamRecordImpl& BamRecordImpl::Position(PacBio::BAM::Position pos)
+BamRecordImpl& BamRecordImpl::Position(Data::Position pos)
 {
     d_->core.pos = pos;
     return *this;
@@ -414,18 +417,18 @@ BamRecordImpl& BamRecordImpl::Name(const std::string& name)
     return *this;
 }
 
-QualityValues BamRecordImpl::Qualities() const
+Data::QualityValues BamRecordImpl::Qualities() const
 {
-    if (d_->core.l_qseq == 0) return QualityValues();
+    if (d_->core.l_qseq == 0) return Data::QualityValues();
 
     uint8_t* qualData = bam_get_qual(d_);
-    if (qualData[0] == 0xff) return QualityValues();
+    if (qualData[0] == 0xff) return Data::QualityValues();
 
     const size_t numQuals = d_->core.l_qseq;
-    QualityValues result;
+    Data::QualityValues result;
     result.reserve(numQuals);
     for (size_t i = 0; i < numQuals; ++i)
-        result.push_back(QualityValue(qualData[i]));
+        result.push_back(Data::QualityValue(qualData[i]));
     return result;
 }
 
@@ -463,7 +466,7 @@ std::string BamRecordImpl::Sequence() const
 
 size_t BamRecordImpl::SequenceLength() const { return d_->core.l_qseq; }
 
-void BamRecordImpl::SetCigarData(const Cigar& cigar)
+void BamRecordImpl::SetCigarData(const Data::Cigar& cigar)
 {
     // determine change in memory needed
     // diffNumBytes: pos -> growing, neg -> shrinking
@@ -484,7 +487,7 @@ void BamRecordImpl::SetCigarData(const Cigar& cigar)
     // fill in new CIGAR data
     uint32_t* cigarDataStart = bam_get_cigar(d_);
     for (size_t i = 0; i < numCigarOps; ++i) {
-        const CigarOperation& cigarOp = cigar.at(i);
+        const Data::CigarOperation& cigarOp = cigar.at(i);
         cigarDataStart[i] = bam_cigar_gen(cigarOp.Length(), static_cast<int>(cigarOp.Type()));
     }
 }
@@ -693,7 +696,9 @@ BamRecordImpl& BamRecordImpl::Tags(const TagCollection& tags)
     tagStart = bam_get_aux(d_);
 
     // fill in new tag data
-    memcpy(static_cast<void*>(tagStart), data, numBytes);
+    if (numBytes) {
+        std::memcpy(static_cast<void*>(tagStart), data, numBytes);
+    }
 
     // update tag info
     UpdateTagMap();
