@@ -1,12 +1,6 @@
-// File Description
-/// \file BamTagCodec.cpp
-/// \brief Implements the BamTagCodec class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/BamTagCodec.h"
+#include <pbbam/BamTagCodec.h>
 
 #include <cstddef>
 #include <cstdint>
@@ -19,21 +13,27 @@ namespace BAM {
 namespace {
 
 template <typename T>
-inline void appendBamValue(const T& value, kstring_t* str)
+void appendBamValue(const T& value, kstring_t* str)
 {
     kputsn_(reinterpret_cast<const char*>(&value), sizeof(value), str);
 }
 
 template <typename T>
-inline void appendBamMultiValue(const std::vector<T>& container, kstring_t* str)
+void appendBamMultiValue(const std::vector<T>& container, kstring_t* str)
 {
     const uint32_t n = container.size();
     kputsn_(&n, sizeof(n), str);
-    kputsn_(reinterpret_cast<const char*>(&container[0]), n * sizeof(T), str);
+
+    // If n == 0, then `container.data()` **might** return a nullptr.
+    // kputsn_() internally memcpy's data from the first pointer, and
+    // if this is a nullptr, we invoke undefined behavior on memcpy.
+    if (n) {
+        kputsn_(reinterpret_cast<const char*>(container.data()), n * sizeof(T), str);
+    }
 }
 
 template <typename T>
-inline T readBamValue(const uint8_t* src, size_t& offset)
+T readBamValue(const uint8_t* src, size_t& offset)
 {
     T value;
     memcpy(&value, &src[offset], sizeof(value));
@@ -109,7 +109,7 @@ TagCollection BamTagCodec::Decode(const std::vector<uint8_t>& data)
             case 'Z':
             case 'H': {
                 const size_t dataLength = strlen(reinterpret_cast<const char*>(&pData[i]));
-                std::string value(reinterpret_cast<const char*>(&pData[i]), dataLength);
+                const std::string value(reinterpret_cast<const char*>(&pData[i]), dataLength);
                 tags[tagName] = value;
                 if (tagType == 'H') tags[tagName].Modifier(TagModifier::HEX_STRING);
                 i += dataLength + 1;
@@ -292,8 +292,10 @@ std::vector<uint8_t> BamTagCodec::Encode(const TagCollection& tags)
 
     std::vector<uint8_t> result;
     result.resize(str.l);
-    memcpy(reinterpret_cast<char*>(result.data()), str.s, str.l);
-    free(str.s);
+    if (str.l) {
+        std::memcpy(reinterpret_cast<char*>(result.data()), str.s, str.l);
+    }
+    std::free(str.s);
     return result;
 }
 
@@ -327,7 +329,7 @@ Tag BamTagCodec::FromRawData(uint8_t* rawData)
         case 'Z':
         case 'H': {
             const size_t dataLength = strlen(reinterpret_cast<const char*>(&rawData[0]));
-            std::string value(reinterpret_cast<const char*>(&rawData[0]), dataLength);
+            const std::string value(reinterpret_cast<const char*>(&rawData[0]), dataLength);
             Tag t{value};
             if (tagType == 'H') t.Modifier(TagModifier::HEX_STRING);
             return t;
@@ -367,7 +369,7 @@ Tag BamTagCodec::FromRawData(uint8_t* rawData)
                 "[pbbam] BAM tag format ERROR: unsupported tag-type encountered: " +
                 std::string{1, tagType}};
     }
-    return Tag();  // to avoid compiler warning
+    return {};
 }
 
 std::vector<uint8_t> BamTagCodec::ToRawData(const Tag& tag, const TagModifier& additionalModifier)
@@ -546,7 +548,7 @@ uint8_t BamTagCodec::TagTypeCode(const Tag& tag, const TagModifier& additionalMo
                 "[pbbam] BAM tag format ERROR: unsupported tag-type encountered: " +
                 std::to_string(static_cast<uint16_t>(tag.Type()))};
     }
-    return 0;  // to avoid compiler warning
+    return 0;
 }
 
 }  // namespace BAM
