@@ -1,19 +1,13 @@
-// File Description
-/// \file BgzipFastqWriter.cpp
-/// \brief Implements the BgzipFastqWriter class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/BgzipFastqWriter.h"
+#include <pbbam/BgzipFastqWriter.h>
 
 #include <sstream>
 #include <stdexcept>
 
-#include "pbbam/BamRecord.h"
-#include "pbbam/FastqSequence.h"
-#include "pbbam/FormatUtils.h"
+#include <pbbam/BamRecord.h>
+#include <pbbam/FastqSequence.h>
+#include <pbbam/FormatUtils.h>
 
 namespace PacBio {
 namespace BAM {
@@ -34,8 +28,6 @@ BgzipFastqWriter::BgzipFastqWriter(const std::string& fn, const BgzipWriterConfi
     }
 }
 
-void BgzipFastqWriter::TryFlush() {}
-
 void BgzipFastqWriter::Write(const FastqSequence& fastq)
 {
     Write(fastq.Name(), fastq.Bases(), fastq.Qualities());
