@@ -1,11 +1,7 @@
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/CollectionMetadata.h"
+#include <pbbam/CollectionMetadata.h>
 
-#include <fstream>
-#include <iostream>
 #include <sstream>
 #include <stdexcept>
 #include <tuple>
@@ -15,6 +11,7 @@
 
 #include "DataSetUtils.h"
 #include "RunMetadataParser.h"
+#include "pugixml/pugixml.hpp"
 
 namespace PacBio {
 namespace BAM {
@@ -24,7 +21,7 @@ boost::optional<ControlKit::CustomSequence> UpdateControlKitCache(const ControlK
 {
     if (!kit.HasChild("CustomSequence")) return boost::none;
 
-    const std::string& customSeq = kit.ChildText("CustomSequence");
+    const auto& customSeq = kit.ChildText("CustomSequence");
     const auto lines = [](const std::string& input) {
         std::vector<std::string> result;
         size_t pos = 0;
@@ -56,6 +53,49 @@ void UpdateControlKit(const boost::optional<ControlKit::CustomSequence>& cache,
     kit.ChildText("CustomSequence", seq.str());
 }
 
+void CollectionMetadataElementFromXml(const pugi::xml_node& xmlNode,
+                                      internal::DataSetElement& parent)
+{
+    const std::string label = xmlNode.name();
+    if (label.empty()) return;
+
+    // TODO(DB): This is getting a bit 'hacky'. Should revisit namespace-
+    //           handling internally.
+    ///
+    // ensure 'pbmeta' namespace for child elements, except for:
+    //  - 'AutomationParameter' & 'AutomationParameters' which are 'pbbase'
+    //  - 'BioSample' & 'BioSamples' which are 'pbsample'
+    ///
+    const XsdType xsdType = [&]() {
+        if (label.find("BioSample") != std::string::npos)
+            return XsdType::SAMPLE_INFO;
+        else if (label.find("AutomationParameter") != std::string::npos)
+            return XsdType::BASE_DATA_MODEL;
+        else
+            return XsdType::COLLECTION_METADATA;
+    }();
+
+    internal::DataSetElement e{label, xsdType};
+    e.Text(xmlNode.text().get());
+
+    // iterate attributes
+    auto attrIter = xmlNode.attributes_begin();
+    auto attrEnd = xmlNode.attributes_end();
+    for (; attrIter != attrEnd; ++attrIter) {
+        e.Attribute(attrIter->name(), attrIter->value());
+    }
+
+    // iterate children, recursively building up subtree
+    auto childIter = xmlNode.begin();
+    auto childEnd = xmlNode.end();
+    for (; childIter != childEnd; ++childIter) {
+        pugi::xml_node childNode = *childIter;
+        CollectionMetadataElementFromXml(childNode, e);
+    }
+
+    parent.AddChild(e);
+}
+
 }  // namespace
 
 // ----------------------
@@ -71,7 +111,7 @@ Automation::Automation(const internal::FromInputXml& fromInputXml)
 
 DEFINE_ACCESSORS(Automation, AutomationParameters, AutomationParameters)
 
-Automation& Automation::AutomationParameters(PacBio::BAM::AutomationParameters params)
+Automation& Automation::AutomationParameters(BAM::AutomationParameters params)
 {
     AutomationParameters() = params;
     return *this;
@@ -695,7 +735,7 @@ const std::string& CollectionMetadata::SubreadSetName() const { return subreadSe
 
 DEFINE_ACCESSORS(CollectionMetadata, Automation, Automation)
 
-CollectionMetadata& CollectionMetadata::Automation(PacBio::BAM::Automation automation)
+CollectionMetadata& CollectionMetadata::Automation(BAM::Automation automation)
 {
     Automation() = automation;
     return *this;
@@ -703,22 +743,21 @@ CollectionMetadata& CollectionMetadata::Automation(PacBio::BAM::Automation autom
 
 bool CollectionMetadata::HasAutomation() const { return HasChild(Element::Automation); }
 
-const PacBio::BAM::AutomationParameters& CollectionMetadata::AutomationParameters() const
+const BAM::AutomationParameters& CollectionMetadata::AutomationParameters() const
 {
-    const PacBio::BAM::Automation& automation = Automation();
+    const BAM::Automation& automation = Automation();
     return automation.AutomationParameters();
 }
 
-PacBio::BAM::AutomationParameters& CollectionMetadata::AutomationParameters()
+BAM::AutomationParameters& CollectionMetadata::AutomationParameters()
 {
-    PacBio::BAM::Automation& automation = Automation();
+    BAM::Automation& automation = Automation();
     return automation.AutomationParameters();
 }
 
-CollectionMetadata& CollectionMetadata::AutomationParameters(
-    PacBio::BAM::AutomationParameters params)
+CollectionMetadata& CollectionMetadata::AutomationParameters(BAM::AutomationParameters params)
 {
-    // PacBio::BAM::Automation& automation = Automation();
+    // BAM::Automation& automation = Automation();
     AutomationParameters() = params;
     return *this;
 }
@@ -730,7 +769,7 @@ bool CollectionMetadata::HasAutomationParameters() const
 
 DEFINE_ACCESSORS(CollectionMetadata, BindingKit, BindingKit)
 
-CollectionMetadata& CollectionMetadata::BindingKit(PacBio::BAM::BindingKit kit)
+CollectionMetadata& CollectionMetadata::BindingKit(BAM::BindingKit kit)
 {
     BindingKit() = std::move(kit);
     return *this;
@@ -740,7 +779,7 @@ bool CollectionMetadata::HasBindingKit() const { return HasChild("BindingKit");
 
 DEFINE_ACCESSORS(CollectionMetadata, ControlKit, ControlKit)
 
-CollectionMetadata& CollectionMetadata::ControlKit(PacBio::BAM::ControlKit kit)
+CollectionMetadata& CollectionMetadata::ControlKit(BAM::ControlKit kit)
 {
     ControlKit() = std::move(kit);
     return *this;
@@ -750,7 +789,7 @@ bool CollectionMetadata::HasControlKit() const { return HasChild("ControlKit");
 
 DEFINE_ACCESSORS(CollectionMetadata, PPAConfig, PPAConfig)
 
-CollectionMetadata& CollectionMetadata::PPAConfig(PacBio::BAM::PPAConfig config)
+CollectionMetadata& CollectionMetadata::PPAConfig(BAM::PPAConfig config)
 {
     PPAConfig() = std::move(config);
     return *this;
@@ -760,7 +799,7 @@ bool CollectionMetadata::HasPPAConfig() const { return HasChild("PPAConfig"); }
 
 DEFINE_ACCESSORS(CollectionMetadata, SequencingKitPlate, SequencingKitPlate)
 
-CollectionMetadata& CollectionMetadata::SequencingKitPlate(PacBio::BAM::SequencingKitPlate kit)
+CollectionMetadata& CollectionMetadata::SequencingKitPlate(BAM::SequencingKitPlate kit)
 {
     SequencingKitPlate() = std::move(kit);
     return *this;
@@ -770,7 +809,7 @@ bool CollectionMetadata::HasSequencingKitPlate() const { return HasChild("Sequen
 
 DEFINE_ACCESSORS(CollectionMetadata, TemplatePrepKit, TemplatePrepKit)
 
-CollectionMetadata& CollectionMetadata::TemplatePrepKit(PacBio::BAM::TemplatePrepKit kit)
+CollectionMetadata& CollectionMetadata::TemplatePrepKit(BAM::TemplatePrepKit kit)
 {
     TemplatePrepKit() = std::move(kit);
     return *this;
@@ -778,5 +817,39 @@ CollectionMetadata& CollectionMetadata::TemplatePrepKit(PacBio::BAM::TemplatePre
 
 bool CollectionMetadata::HasTemplatePrepKit() const { return HasChild("TemplatePrepKit"); }
 
+CollectionMetadata CollectionMetadata::FromRawXml(const std::string& input)
+{
+    // load XML
+    pugi::xml_document doc;
+    const pugi::xml_parse_result loadResult = doc.load_string(input.c_str());
+    if (loadResult.status != pugi::status_ok) {
+        throw std::runtime_error{
+            "[pbbam] dataset ERROR: could not create CollectionMetadata from raw XML, error code:" +
+            std::to_string(loadResult.status)};
+    }
+    pugi::xml_node rootNode = doc.document_element();
+
+    // top-level attributes
+    CollectionMetadata cm{internal::FromInputXml{}};
+    cm.Label(rootNode.name());
+    auto attributeIter = rootNode.attributes_begin();
+    auto attributeEnd = rootNode.attributes_end();
+    for (; attributeIter != attributeEnd; ++attributeIter) {
+        std::string name = attributeIter->name();
+        std::string value = attributeIter->value();
+        cm.Attribute(std::move(name), std::move(value));
+    }
+
+    // iterate children, recursively building up subtree
+    auto childIter = rootNode.begin();
+    auto childEnd = rootNode.end();
+    for (; childIter != childEnd; ++childIter) {
+        pugi::xml_node childNode = *childIter;
+        CollectionMetadataElementFromXml(childNode, cm);
+    }
+
+    return cm;
+}
+
 }  // namespace BAM
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
