@@ -1,14 +1,11 @@
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
 #include "FofnReader.h"
 
-#include <iostream>
+#include <istream>
 
 namespace PacBio {
 namespace BAM {
-namespace internal {
 
 std::vector<std::string> FofnReader::Files(std::istream& in)
 {
@@ -19,6 +16,5 @@ std::vector<std::string> FofnReader::Files(std::istream& in)
     return files;
 }
 
-}  // namespace internal
 }  // namespace BAM
 }  // namespace PacBio
