@@ -1,21 +1,17 @@
-// File Description
-/// \file IndexedFastqBgzfReader.h
-/// \brief Defines the IndexedFastqBgzfReader class.
-//
-// Author: Derek Barnett
+#ifndef PBBAM_INDEXEDFASTQBGZFREADER_H
+#define PBBAM_INDEXEDFASTQBGZFREADER_H
 
-#ifndef INDEXEDFASTQBGZFREADER_H
-#define INDEXEDFASTQBGZFREADER_H
-
-#include "pbbam/Config.h"
+#include <pbbam/Config.h>
 
 #include "IndexedFastqReaderImpl.h"
 
 #include <memory>
 
 #include <htslib/kseq.h>
+#include <pbcopper/data/Position.h>
+#include <pbcopper/data/QualityValues.h>
 
-#include "MemoryUtils.h"
+#include <pbbam/Deleters.h>
 
 namespace PacBio {
 namespace BAM {
@@ -25,8 +21,9 @@ class IndexedFastqBgzfReader final : public IndexedFastqReaderImpl
 public:
     IndexedFastqBgzfReader(std::string filename);
 
-    std::pair<std::string, QualityValues> Subsequence(const std::string& id, Position start,
-                                                      Position end) final;
+    std::pair<std::string, Data::QualityValues> Subsequence(const std::string& id,
+                                                            Data::Position start,
+                                                            Data::Position end) final;
 
 private:
     int FetchRecord();
@@ -35,7 +32,7 @@ private:
     KSEQ_INIT(BGZF*, bgzf_read);
     struct KSeqDeleter
     {
-        void operator()(kseq_t* seq) const
+        void operator()(kseq_t* seq) const noexcept
         {
             if (seq) kseq_destroy(seq);
             seq = nullptr;
@@ -49,4 +46,4 @@ private:
 }  // namespace BAM
 }  // namespace PacBio
 
-#endif  // INDEXEDFASTQBGZFREADER_H
\ No newline at end of file
+#endif  // PBBAM_INDEXEDFASTQBGZFREADER_H
