@@ -1,21 +1,15 @@
-// File Description
-/// \file IndexedFastqReader.cpp
-/// \brief Implements the IndexedFastqReader class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/IndexedFastqReader.h"
+#include <pbbam/IndexedFastqReader.h>
 
 #include <sstream>
 #include <stdexcept>
 #include <utility>
 
-#include "pbbam/BamRecord.h"
-#include "pbbam/FaiIndex.h"
-#include "pbbam/FormatUtils.h"
-#include "pbbam/GenomicInterval.h"
+#include <pbbam/BamRecord.h>
+#include <pbbam/FaiIndex.h>
+#include <pbbam/FormatUtils.h>
+#include <pbbam/GenomicInterval.h>
 
 #include "IndexedFastqBgzfReader.h"
 #include "IndexedFastqReaderImpl.h"
@@ -27,13 +21,13 @@ namespace BAM {
 
 namespace {
 
-void ClipAndGapify(std::pair<std::string, QualityValues>& seqQual, const Cigar& cigar,
+void ClipAndGapify(std::pair<std::string, Data::QualityValues>& seqQual, const Data::Cigar& cigar,
                    bool exciseSoftClips)
 {
     auto& subseq = seqQual.first;
     auto subQual = seqQual.second.Fastq();
 
-    const char nullQual = QualityValue{0}.Fastq();
+    const char nullQual = Data::QualityValue{0}.Fastq();
 
     size_t seqIndex = 0;
     for (const auto& op : cigar) {
@@ -41,10 +35,10 @@ void ClipAndGapify(std::pair<std::string, QualityValues>& seqQual, const Cigar&
         const auto opLength = op.Length();
 
         // do nothing for hard clips
-        if (type == CigarOperationType::HARD_CLIP) continue;
+        if (type == Data::CigarOperationType::HARD_CLIP) continue;
 
         // maybe remove soft clips
-        if (type == CigarOperationType::SOFT_CLIP) {
+        if (type == Data::CigarOperationType::SOFT_CLIP) {
             if (!exciseSoftClips) {
                 subseq.reserve(subseq.size() + opLength);
                 subseq.insert(seqIndex, opLength, '-');
@@ -57,12 +51,12 @@ void ClipAndGapify(std::pair<std::string, QualityValues>& seqQual, const Cigar&
         // for non-clipping operations
         else {
             // maybe add gaps/padding
-            if (type == CigarOperationType::INSERTION) {
+            if (type == Data::CigarOperationType::INSERTION) {
                 subseq.reserve(subseq.size() + opLength);
                 subseq.insert(seqIndex, opLength, '-');
                 subQual.reserve(subseq.size() + opLength);
                 subQual.insert(seqIndex, opLength, nullQual);
-            } else if (type == CigarOperationType::PADDING) {
+            } else if (type == Data::CigarOperationType::PADDING) {
                 subseq.reserve(subseq.size() + opLength);
                 subseq.insert(seqIndex, opLength, '*');
                 subQual.reserve(subseq.size() + opLength);
@@ -74,7 +68,7 @@ void ClipAndGapify(std::pair<std::string, QualityValues>& seqQual, const Cigar&
         }
     }
 
-    seqQual.second = QualityValues::FromFastq(subQual);
+    seqQual.second = Data::QualityValues::FromFastq(subQual);
 }
 
 std::unique_ptr<IndexedFastqReaderImpl> MakeReaderImpl(std::string filename)
@@ -157,8 +151,8 @@ std::string IndexedFastqReader::Name(const size_t idx) const { return d_->index_
 
 int IndexedFastqReader::NumSequences() const { return d_->index_.Names().size(); }
 
-std::pair<std::string, QualityValues> IndexedFastqReader::ReferenceSubsequence(
-    const BamRecord& bamRecord, const Orientation orientation, const bool gapped,
+std::pair<std::string, Data::QualityValues> IndexedFastqReader::ReferenceSubsequence(
+    const BamRecord& bamRecord, const Data::Orientation orientation, const bool gapped,
     const bool exciseSoftClips)
 {
     // fetch raw data for record's region
@@ -172,7 +166,7 @@ std::pair<std::string, QualityValues> IndexedFastqReader::ReferenceSubsequence(
 
     // maybe reverse
     const auto reverse =
-        (orientation != Orientation::GENOMIC) && bamRecord.Impl().IsReverseStrand();
+        (orientation != Data::Orientation::GENOMIC) && bamRecord.Impl().IsReverseStrand();
     if (reverse) {
         ReverseComplementCaseSens(seqQual.first);
         Reverse(seqQual.second);
@@ -187,17 +181,18 @@ int IndexedFastqReader::SequenceLength(const std::string& name) const
     return static_cast<int>(entry.Length);
 }
 
-std::pair<std::string, QualityValues> IndexedFastqReader::Subsequence(const std::string& id,
-                                                                      Position start, Position end)
+std::pair<std::string, Data::QualityValues> IndexedFastqReader::Subsequence(const std::string& id,
+                                                                            Data::Position start,
+                                                                            Data::Position end)
 {
     return d_->Subsequence(id, start, end);
 }
 
 std::pair<std::string, QualityValues> IndexedFastqReader::Subsequence(
-    const GenomicInterval& interval)
+    const Data::GenomicInterval& interval)
 {
     return Subsequence(interval.Name(), interval.Start(), interval.Stop());
 }
 
 }  // namespace BAM
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
