@@ -1,17 +1,15 @@
-// File Description
-/// \file KSeqReader.cpp
-/// \brief Implements the KSeqReader class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
 #include "KSeqReader.h"
 
-#include <iostream>
+#include <cassert>
+
+#include <sstream>
 #include <stdexcept>
 #include <vector>
 
+#include "ErrnoReason.h"
+
 namespace PacBio {
 namespace BAM {
 
@@ -23,6 +21,7 @@ KSeqReader::KSeqReader(const std::string& fn)
         std::ostringstream msg;
         msg << "[pbbam] kseq FASTX reader ERROR: could not open file:\n"
             << "  file: " << fn << '\n';
+        MaybePrintErrnoReason(msg);
         throw std::runtime_error{msg.str()};
     }
 
