@@ -1,9 +1,8 @@
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
+#include <pbbam/RunMetadata.h>
+
 #include "RunMetadataParser.h"
-#include "pbbam/RunMetadata.h"
 
 namespace PacBio {
 namespace BAM {
@@ -33,4 +32,4 @@ std::map<std::string, CollectionMetadata> RunMetadata::Collections(std::istream&
 }
 
 }  // namespace BAM
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
