@@ -1,26 +1,20 @@
-
-// File Description
-/// \file TextFileWriter.cpp
-/// \brief Implements the TextFileWriter class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/TextFileWriter.h"
+#include <pbbam/TextFileWriter.h>
 
 #include <cassert>
 
 #include <fstream>
-#include <iostream>
 #include <sstream>
 #include <stdexcept>
 #include <type_traits>
 
 #include <boost/algorithm/string.hpp>
 
+#include <pbbam/Deleters.h>
+
+#include "ErrnoReason.h"
 #include "FileProducer.h"
-#include "MemoryUtils.h"
 
 namespace PacBio {
 namespace BAM {
@@ -44,6 +38,7 @@ public:
                 std::ostringstream msg;
                 msg << "[pbbam] text file writer ERROR: could not open zipped file:\n"
                     << "  file: " << filename;
+                MaybePrintErrnoReason(msg);
                 throw std::runtime_error{msg.str()};
             }
         } else {
@@ -53,6 +48,7 @@ public:
                 std::ostringstream msg;
                 msg << "[pbbam] text file writer ERROR: could not open plain text file:\n"
                     << "  file: " << filename;
+                MaybePrintErrnoReason(msg);
                 throw std::runtime_error{msg.str()};
             }
         }
@@ -68,6 +64,7 @@ public:
                 std::ostringstream msg;
                 msg << "[pbbam] text file writer ERROR: could not write to file:\n"
                     << "  file: " << TempFilename();
+                MaybePrintErrnoReason(msg);
                 throw std::runtime_error{msg.str()};
             }
         } else {
@@ -94,4 +91,4 @@ TextFileWriter::~TextFileWriter() = default;
 void TextFileWriter::Write(const std::string& line) { d_->Write(line); }
 
 }  // namespace BAM
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
