@@ -1,17 +1,12 @@
-// File Description
-/// \file Version.cpp
-/// \brief Implements the Version class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
 #include "Version.h"
 
+#include <ostream>
 #include <sstream>
 #include <stdexcept>
 
-#include "pbbam/StringUtilities.h"
+#include <pbbam/StringUtilities.h>
 
 namespace PacBio {
 namespace BAM {
@@ -52,5 +47,11 @@ std::string Version::ToString() const
     return s.str();
 }
 
+std::ostream& operator<<(std::ostream& out, const Version& version)
+{
+    out << version.ToString();
+    return out;
+}
+
 }  // namespace BAM
 }  // namespace PacBio
