@@ -1,9 +1,3 @@
-// File Description
-/// \file ZmwChunkedFastxTextReader.cpp
-/// \brief Implements the ZmwChunkedFastxTextReader class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
 #include "ZmwChunkedFastxTextReader.h"
@@ -13,11 +7,12 @@
 #include <cassert>
 #include <cstdio>
 
-#include <iostream>
 #include <memory>
 #include <sstream>
 #include <stdexcept>
 
+#include "ErrnoReason.h"
+
 namespace PacBio {
 namespace BAM {
 
@@ -31,6 +26,7 @@ ZmwChunkedFastxTextReader::ZmwChunkedFastxTextReader(std::string filename, const
         std::ostringstream msg;
         msg << "[pbbam] chunked FASTX reader ERROR: could not open file:\n"
             << "  file: " << fastxFilename_ << '\n';
+        MaybePrintErrnoReason(msg);
         throw std::runtime_error{msg.str()};
     }
 
@@ -150,6 +146,7 @@ void ZmwChunkedFastxTextReader::Seek(uint64_t pos)
         msg << "[pbbam] chunked FASTX reader ERROR: could not seek to requested pos: " << pos
             << '\n'
             << "  in file: " << fastxFilename_;
+        MaybePrintErrnoReason(msg);
         throw std::runtime_error{msg.str()};
     }
     ks_rewind(seq_->f);
