@@ -1,16 +1,13 @@
-// File Description
-/// \file CCSPbiBuilder.cpp
-/// \brief Implements the CCSPbiBuilder.cpp class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/ccs/CCSPbiBuilder.h"
+#include <pbbam/ccs/CCSPbiBuilder.h>
 
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
 
+#include <array>
+#include <limits>
 #include <sstream>
 #include <stdexcept>
 #include <thread>
@@ -19,21 +16,23 @@
 #include <htslib/bgzf.h>
 #include <pbcopper/utility/Deleters.h>
 
-#include "pbbam/PbiBuilder.h"
-#include "pbbam/PbiFile.h"
-#include "pbbam/ccs/CCSHeader.h"
-#include "pbbam/ccs/CCSRecord.h"
+#include <pbbam/Deleters.h>
+#include <pbbam/PbiBuilder.h>
+#include <pbbam/PbiFile.h>
+#include <pbbam/ReadGroupInfo.h>
+#include <pbbam/ccs/CCSHeader.h>
+#include <pbbam/ccs/CCSRecord.h>
 
-#include "MemoryUtils.h"
+#include "ErrnoReason.h"
 
 namespace PacBio {
 namespace CCS {
 namespace internal {
 
 template <typename T>
-inline void SwapEndianness(std::vector<T>& data)
+void SwapEndianness(std::vector<T>& data)
 {
-    const size_t elementSize = sizeof(T);
+    constexpr const size_t elementSize = sizeof(T);
     const size_t numReads = data.size();
     switch (elementSize) {
         case 1:
@@ -59,14 +58,16 @@ inline void SwapEndianness(std::vector<T>& data)
 void bgzf_write_safe(BGZF* fp, const void* data, size_t length)
 {
     const auto ret = bgzf_write(fp, data, length);
-    if (ret < 0L)
-        throw std::runtime_error{
-            "[pbbam] PBI index builder ERROR: non-zero returned from bgzf_write(). Out of disk "
-            "space?"};
+    if (ret < 0L) {
+        std::ostringstream msg;
+        msg << "[pbbam] PBI index builder ERROR: could not write to\n";
+        BAM::MaybePrintErrnoReason(msg);
+        throw std::runtime_error{msg.str()};
+    }
 }
 
 template <typename T>
-inline void WriteBgzfVector(BGZF* fp, std::vector<T>& data)
+void WriteBgzfVector(BGZF* fp, std::vector<T>& data)
 {
     assert(fp);
     if (fp->is_be) SwapEndianness(data);
@@ -139,7 +140,7 @@ public:
         holeNumField_.Add(record.HoleNumber);
         ctxtField_.Add(record.LocalContextFlags);
         readQualField_.Add(record.Accuracy);
-        fileOffsetField_.Add(-1);
+        fileOffsetField_.Add(std::numeric_limits<uint64_t>::max());
 
         FlushBuffers(FlushMode::NO_FORCE);
         ++currentRow_;
@@ -225,9 +226,9 @@ public:
         static constexpr const std::array<char, 4> magic{{'P', 'B', 'I', '\1'}};
         internal::bgzf_write_safe(bgzf, magic.data(), 4);
 
-        PacBio::BAM::PbiFile::Sections sections = PacBio::BAM::PbiFile::BASIC;
+        const BAM::PbiFile::Sections sections = BAM::PbiFile::BASIC;
         // version, pbi_flags, & n_reads
-        auto version = static_cast<uint32_t>(PacBio::BAM::PbiFile::CurrentVersion);
+        auto version = static_cast<uint32_t>(BAM::PbiFile::CurrentVersion);
         uint16_t pbi_flags = sections;
         auto numReads = currentRow_;
         if (bgzf->is_be) {
@@ -252,11 +253,12 @@ public:
         // seek to block begin
         const auto ret = std::fseek(tempFile_.get(), block.pos_, SEEK_SET);
         if (ret != 0) {
-            std::ostringstream msg;
-            msg << "[pbbam] PBI builder ERROR: could not seek in temp file:\n"
-                << "  file: " << tempFilename_ << '\n'
-                << "  offset: " << block.pos_ << '\n';
-            throw std::runtime_error{msg.str()};
+            std::ostringstream s;
+            s << "[pbbam] PBI index builder ERROR: could not seek in temp file:\n"
+              << "  file: " << tempFilename_ << '\n'
+              << "  offset: " << block.pos_;
+            BAM::MaybePrintErrnoReason(s);
+            throw std::runtime_error{s.str()};
         }
 
         // read block elements
@@ -268,6 +270,7 @@ public:
             std::ostringstream msg;
             msg << "[pbbam] PBI builder ERROR: could not read element count from temp file\n"
                 << "  file: " << tempFilename_ << '\n';
+            BAM::MaybePrintErrnoReason(msg);
             throw std::runtime_error{msg.str()};
         }
     }
@@ -298,9 +301,8 @@ public:
     std::string pbiFilename_;
     std::string tempFilename_;
     std::unique_ptr<FILE, Utility::FileDeleter> tempFile_;
-    std::unique_ptr<BGZF, PacBio::BAM::HtslibBgzfDeleter> pbiFile_;
-    PacBio::BAM::PbiBuilder::CompressionLevel compressionLevel_ =
-        PacBio::BAM::PbiBuilder::DefaultCompression;
+    std::unique_ptr<BGZF, BAM::HtslibBgzfDeleter> pbiFile_;
+    BAM::PbiBuilder::CompressionLevel compressionLevel_ = BAM::PbiBuilder::DefaultCompression;
     size_t numThreads_;
 
     // PBI field buffers
@@ -339,4 +341,4 @@ void CCSPbiBuilder::Close() { d_->Close(); }
 const std::string& CCSPbiBuilder::MovieName() const { return d_->movieName_; }
 
 }  // namespace CCS
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
