@@ -1,19 +1,14 @@
-// File Description
-/// \file CCSRecordReader.cpp
-/// \brief Implements the CCSRecordReader class.
-//
-// Author: Derek Barnett
-
 #include "PbbamInternalConfig.h"
 
-#include "pbbam/ccs/CCSRecordReader.h"
+#include <pbbam/ccs/CCSRecordReader.h>
 
 #include <iostream>
+#include <istream>
 #include <stdexcept>
 #include <string>
 #include <vector>
 
-#include "pbbam/ccs/CCSRecordFormat.h"
+#include <pbbam/ccs/CCSRecordFormat.h>
 
 namespace PacBio {
 namespace CCS {
@@ -62,4 +57,4 @@ bool CCSRecordReader::GetNext(CCSRecord& record) { return d_->GetNext(record); }
 const CCSHeader& CCSRecordReader::Header() const { return d_->header_; }
 
 }  // namespace CCS
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
