@@ -23,10 +23,7 @@ static_assert(std::is_nothrow_move_assignable<VcfQuery>::value ==
 
 VcfQuery::VcfQuery(std::string fn) : VcfQuery{VcfFile{std::move(fn)}} {}
 
-VcfQuery::VcfQuery(const VcfFile& file)
-    : PacBio::BAM::internal::QueryBase<VcfVariant>(), reader_{file}
-{
-}
+VcfQuery::VcfQuery(const VcfFile& file) : BAM::internal::QueryBase<VcfVariant>(), reader_{file} {}
 
 bool VcfQuery::GetNext(VcfVariant& var) { return reader_.GetNext(var); }
 
