@@ -1,5 +1,7 @@
 // Author: Derek Barnett
 
+#include <pbbam/bed/BedWriter.h>
+
 #include <cstdio>
 
 #include <algorithm>
@@ -11,12 +13,11 @@
 #include <pbbam/FormatUtils.h>
 #include <pbbam/GenomicInterval.h>
 #include <pbbam/bed/BedReader.h>
-#include <pbbam/bed/BedWriter.h>
 
 #include "PbbamTestData.h"
 
-using BedReader = PacBio::BAM::BedReader;
-using BedWriter = PacBio::BAM::BedWriter;
+using BedReader = PacBio::BED::BedReader;
+using BedWriter = PacBio::BED::BedWriter;
 using GenomicInterval = PacBio::BAM::GenomicInterval;
 using HtslibCompression = PacBio::BAM::HtslibCompression;
 
@@ -45,19 +46,19 @@ void CheckRoundTrip(const std::string& outFn, const HtslibCompression compressio
 
 }  // namespace BedWriterTests
 
-TEST(BedWriterTest, throws_on_empty_filename)
+TEST(BAM_BedWriter, throws_on_empty_filename)
 {
     EXPECT_THROW(BedWriter writer{""}, std::runtime_error);
 }
 
-TEST(BedWriterTest, can_write_plain_text)
+TEST(BAM_BedWriter, can_write_plain_text)
 {
     const std::string outFn = PacBio::BAM::PbbamTestsConfig::GeneratedData_Dir + "/out.bed";
     BedWriterTests::CheckRoundTrip(outFn, HtslibCompression::NONE);
 }
 
-TEST(BedWriterTest, can_write_gzipped_text)
+TEST(BAM_BedWriter, can_write_gzipped_text)
 {
     const std::string outFn = PacBio::BAM::PbbamTestsConfig::GeneratedData_Dir + "/out.bed.gz";
     BedWriterTests::CheckRoundTrip(outFn, HtslibCompression::GZIP);
-}
\ No newline at end of file
+}
