@@ -1,19 +1,21 @@
 // Author: Derek Barnett
 
+#include <pbbam/BgzipFastqWriter.h>
+
 #include <string>
 
 #include <gtest/gtest.h>
 
-#include <pbbam/BgzipFastqWriter.h>
 #include <pbbam/FastqReader.h>
 #include <pbbam/FastqSequence.h>
 #include <pbbam/FormatUtils.h>
+
 #include "PbbamTestData.h"
 
 using namespace PacBio;
 using namespace PacBio::BAM;
 
-TEST(BgzipFastqWriterTest, writes_bgzf_fastq_data_to_file)
+TEST(BAM_BgzipFastqWriter, writes_bgzf_fastq_data_to_file)
 {
     const std::string fn{PbbamTestsConfig::GeneratedData_Dir + "/bgzf_fastq_out.fq.gz"};
 
@@ -31,4 +33,4 @@ TEST(BgzipFastqWriterTest, writes_bgzf_fastq_data_to_file)
 
     const auto observed = FastqReader::ReadAll(fn);
     EXPECT_TRUE(std::equal(sequences.cbegin(), sequences.cend(), observed.cbegin()));
-}
\ No newline at end of file
+}
