@@ -1,17 +1,19 @@
 // Author: Derek Barnett
 
+#include <pbbam/BgzipWriter.h>
+
 #include <string>
 
 #include <gtest/gtest.h>
 
-#include <pbbam/BgzipWriter.h>
 #include <pbbam/FormatUtils.h>
+
 #include "PbbamTestData.h"
 
 using namespace PacBio;
 using namespace PacBio::BAM;
 
-TEST(BgzipWriterTest, writes_bgzf_format_to_file)
+TEST(BAM_BgzipWriter, writes_bgzf_format_to_file)
 {
     const std::string fn{PbbamTestsConfig::GeneratedData_Dir + "/bgzf_writer_out.gz"};
 
