@@ -1,46 +1,46 @@
 // Author: Derek Barnett
 
+#include <pbbam/IndexedFastqReader.h>
+
 #include <gtest/gtest.h>
 
 #include <htslib/hts.h>
 
-#include <pbbam/IndexedFastqReader.h>
-
 #include "FastxTests.h"
 #include "PbbamTestData.h"
 
 using namespace PacBio;
 using namespace PacBio::BAM;
 
-TEST(IndexedFastqReaderTest, throws_on_empty_filename)
+TEST(BAM_IndexedFastqReader, throws_on_empty_filename)
 {
     EXPECT_THROW(IndexedFastqReader reader{""}, std::runtime_error);
 }
 
-TEST(IndexedFastqReaderTest, throws_on_invalid_extension)
+TEST(BAM_IndexedFastqReader, throws_on_invalid_extension)
 {
     EXPECT_THROW(IndexedFastqReader reader{"wrong.ext"}, std::runtime_error);
 }
 
-TEST(IndexedFastqReaderTest, can_open_text_fastq)
+TEST(BAM_IndexedFastqReader, can_open_text_fastq)
 {
     const auto& fn = FastxTests::simpleFastqFn;
     EXPECT_NO_THROW(IndexedFastqReader reader{fn});
 }
 
-TEST(IndexedFastqReaderTest, throws_on_gzip_fastq)
+TEST(BAM_IndexedFastqReader, throws_on_gzip_fastq)
 {
     const auto& fn = FastxTests::simpleFastqGzipFn;
     EXPECT_THROW(IndexedFastqReader reader{fn}, std::runtime_error);
 }
 
-TEST(IndexedFastqReaderTest, can_open_bgzf_fastq_for_reading)
+TEST(BAM_IndexedFastqReader, can_open_bgzf_fastq_for_reading)
 {
     const auto& fn = FastxTests::simpleFastqBgzfFn;
     EXPECT_NO_THROW(IndexedFastqReader reader{fn});
 }
 
-TEST(IndexedFastqReaderTest, can_query_index_for_metadata)
+TEST(BAM_IndexedFastqReader, can_query_index_for_metadata)
 {
     const IndexedFastqReader r{FastxTests::simpleFastqFn};
 
@@ -56,7 +56,7 @@ TEST(IndexedFastqReaderTest, can_query_index_for_metadata)
         EXPECT_EQ(FastxTests::ExpectedFastq.at(i).Name(), names.at(i));
 }
 
-TEST(IndexedFastqReaderTest, subsequence_from_text_fastq)
+TEST(BAM_IndexedFastqReader, subsequence_from_text_fastq)
 {
     IndexedFastqReader r{FastxTests::simpleFastqFn};
     {
@@ -79,7 +79,7 @@ TEST(IndexedFastqReaderTest, subsequence_from_text_fastq)
     }
 }
 
-TEST(IndexedFastqReaderTest, subsequence_from_bgzf_fastq)
+TEST(BAM_IndexedFastqReader, subsequence_from_bgzf_fastq)
 {
     IndexedFastqReader r{FastxTests::simpleFastqBgzfFn};
     {
@@ -102,7 +102,7 @@ TEST(IndexedFastqReaderTest, subsequence_from_bgzf_fastq)
     }
 }
 
-TEST(IndexedFastqReaderTest, returns_empty_result_from_empty_region)
+TEST(BAM_IndexedFastqReader, returns_empty_result_from_empty_region)
 {
     IndexedFastqReader r{FastxTests::simpleFastqFn};
     const auto subsequence = r.Subsequence("seq2", 0, 0);
@@ -110,7 +110,7 @@ TEST(IndexedFastqReaderTest, returns_empty_result_from_empty_region)
     EXPECT_TRUE(subsequence.second.empty());
 }
 
-TEST(IndexedFastqReaderTest, throws_if_region_is_malformated)
+TEST(BAM_IndexedFastqReader, throws_if_region_is_malformated)
 {
     IndexedFastqReader r{FastxTests::simpleFastqFn};
 
@@ -123,7 +123,7 @@ TEST(IndexedFastqReaderTest, throws_if_region_is_malformated)
     EXPECT_THROW(r.Subsequence("seq2", -2, -1), std::runtime_error);
 }
 
-TEST(IndexedFastqReaderTest, returns_available_length_if_region_is_longer)
+TEST(BAM_IndexedFastqReader, returns_available_length_if_region_is_longer)
 {
     // i.e. like std::string::substr()
 
