@@ -2,8 +2,7 @@
 
 #include "QueryLookup.h"
 
-#include <iostream>
-#include <ostream>
+#include <sstream>
 #include <string>
 
 #include <pbbam/BamFile.h>
@@ -101,4 +100,4 @@ bool QueryLookup::Find(const std::string& qName, BAM::BamRecord& record) const
 }
 
 }  // namespace PbBamify
-}  // namespace PacBio
\ No newline at end of file
+}  // namespace PacBio
